@@ -1,5 +1,7 @@
-export VN=0.38
+export CVS_RSH=ssh
+export VN=0.44
 export VER=klamav-$VN
+export TAG=v0_44
 cd ..
 TOPDIR=$PWD
 cd Releases
@@ -11,7 +13,7 @@ mkdir -p "$VER/Source Update"
 
 #create installer package
 cd "$VER/First Install/klamav"
-cvs -z3 -d:ext:hoganrobert@klamav.cvs.sourceforge.net:/cvsroot/klamav co -P klamav
+cvs -z3 -d:ext:hoganrobert@klamav.cvs.sourceforge.net:/cvsroot/klamav export -r $TAG klamav
 mv klamav $VER
 cd $VER
 make -f Makefile.cvs
