@@ -289,10 +289,14 @@ Klamd::~Klamd()
 
 void Klamd::processOutput()
 {
+
+    if(!childproc)
+        return;
+
 	item2 = "";
 	int pos;
 	if ((pos = (childproc->readln(item2))) != -1) {
-    	kdDebug() << item2 << endl;
+    	//kdDebug() << item2 << endl;
 		if ((pos = (item2.find(" FOUND"))) != -1){
 			item2 = item2.stripWhiteSpace();
 			int fnameStartPoint = (item2.find(":") + 1);
@@ -306,7 +310,17 @@ void Klamd::processOutput()
 			if (recursive_box->isChecked())
 				Quarantine(tmpFName.stripWhiteSpace(),tmpVirusName.stripWhiteSpace());
 		}
+		if ((pos = (item2.find("ERROR: Clamuko: Can't register with Dazuko"))) != -1){
+            finish();
+			KMessageBox::information (this,i18n( "Can't Start On-Access Scanning! Check you have read permissions on file /dev/dazuko.") );
+            KNotifyClient::event(kmain->_tray->winId(),i18n( "Can't Start On-Access Scanning!" ), i18n( "Check you have read permissions on file /dev/dazuko." ));
+            return;
+		}
+
+
    	}
+
+
 	childproc->ackRead();
 
 	item2 = "";
@@ -348,16 +362,20 @@ void Klamd::finish()
 	search_button->setEnabled(true);
 	cancel_button->setEnabled(false);
 	//config = KGlobal::config();
-	config->setGroup("Klamd");
-	config->writeEntry("Enabled", "No");
-	
+  	if (!KApplication::kApplication()->closingDown()){
+        config->setGroup("Klamd");
+        config->writeEntry("Enabled", "No");
+    }
+    kmain->clamdStopped();
 	
 	buf += '\n';
-	processOutput();
-    childproc->closeAll();
-    childproc->kill(9);
-	delete childproc;
-	childproc = 0;
+    if (childproc){
+        processOutput();
+        childproc->closeAll();
+        childproc->kill(9);
+        delete childproc;
+        childproc = 0;
+    }
 	klamdAlive = FALSE;
 	enableInputs();
  	if (!(tempFileName.isEmpty()))
@@ -378,8 +396,9 @@ void Klamd::slotCancel()
 
 void Klamd::childExited()
 {
-//    int status = childproc->exitStatus();
-
+//     int status = childproc->exitStatus();
+// 
+//     kdDebug() << "klamd status" << status << endl;
 
     kmain->contextDisable();
     
@@ -533,19 +552,6 @@ void Klamd::writeConf()
 
 	QTextStream &ts = *(tf.textStream());
 
-	//ts << "LocalSocket /tmp/klamd " << "\n";
-    ts << "TCPSocket 9888 " << "\n";
-/*	ts << "MaxDirectoryRecursion 15" << "\n";*/
-	ts << "Foreground" << "\n";
-	ts << "LogFile /dev/stdout" << "\n";
-	ts << "ScanArchive" << "\n";
-	//ts << "ClamukoMaxFileSize " << check_combo->currentText() << "M\n";
-/*	ts << "ArchiveMaxRecursion 5" << "\n";
-	ts << "ArchiveMaxFiles 1000" << "\n";*/
-	ts << "FixStaleSocket" << "\n";
-	ts << "SelfCheck 1800" << "\n";
-	ts << QString("DatabaseDirectory %1").arg(db) << "\n";
-	ts << "ClamukoScanOnLine" << "\n";
 	
 
 
@@ -560,35 +566,44 @@ void Klamd::writeConf()
 	config->setGroup("Klamd");
 
 
-	if (KlamavConfig::executed())
-		ts << "ClamukoScanOnExec" << "\n";
 
 	if (KlamavConfig::created()){
 		ts << "ClamukoScanOnCloseModified" << "\n";
 		clamdcommand = "klamd";
+
+        ts << "TCPSocket 9888 " << "\n";
+        ts << "Foreground" << "\n";
+        ts << "LogFile /dev/stdout" << "\n";
+        ts << "ScanArchive" << "\n";
+        ts << "FixStaleSocket" << "\n";
+        ts << "SelfCheck 1800" << "\n";
+        ts << QString("DatabaseDirectory %1").arg(db) << "\n";
+        ts << "ClamukoScanOnLine" << "\n";
+
+        if (KlamavConfig::executed())
+            ts << "ClamukoScanOnExec " << "\n";
+
 	}else{
 		clamdcommand = "clamd";
+
+        ts << "TCPSocket 9888 " << "\n";
+        ts << "Foreground True" << "\n";
+        ts << "LogFile /dev/stdout" << "\n";
+        ts << "ScanArchive True" << "\n";
+        ts << "FixStaleSocket True" << "\n";
+        ts << "SelfCheck 1800" << "\n";
+        ts << QString("DatabaseDirectory %1").arg(db) << "\n";
+        ts << "ClamukoScanOnAccess True" << "\n";
+
+        if (KlamavConfig::executed())
+            ts << "ClamukoScanOnExec True" << "\n";
 		
 		if (KlamavConfig::opened())
-			ts << "ClamukoScanOnOpen" << "\n";
+			ts << "ClamukoScanOnOpen True" << "\n";
 	
 		if (KlamavConfig::closed())
-			ts << "ClamukoScanOnClose" << "\n";
+			ts << "ClamukoScanOnClose True" << "\n";
 	}
-/*	if (config->readEntry("ScanArchives") == "Yes"){
-		ts << "ClamukoScanArchive" << "\n";
-		ts << "ArchiveMaxFileSize " << config->readEntry("MaxSize") << "M\n";
-	}*/
-//     if (check_combo2->currentItem() == 0)
-// 	ts << "ClamukoScanOnOpen" << "\n";
-//     else
-//     	ts << "ClamukoScanOnExec" << "\n";
-
-//	if (recursive_box1->isChecked())
-//		ts << "ClamukoScanOnClose" << "\n";
-
-//	if (recursive_box2->isChecked())
-//		ts << "ClamukoScanOnExec" << "\n";
 
 	QString curtex = check_combo->currentText();
 	ts << "ClamukoMaxFileSize " << curtex << "M\n";
