@@ -37,6 +37,7 @@
 
 #include "options.h"
 #include "defaults.h"
+#include "memory.h"
 #include "../version.h"
 
 #define BUFFSIZE 1024
@@ -94,13 +95,10 @@ int clamdscan(struct optstruct *opt)
                 unsigned long int size = 0;
                 long double mb;
                 const char *virname;
-                struct cl_node *root = NULL;
+                struct cl_engine *engine = NULL;
                 struct cl_limits limits;
                 struct stat sb;
-                
-                
-                
-                
+
                 if(optc(opt, 'V')) {
                 mprintf("clamdmail "KLAMAV_VERSION" \n");
                 mexit(0);
@@ -139,7 +137,7 @@ int clamdscan(struct optstruct *opt)
                     exit(2);
                 }
 
-		//snprintf(fullname, sizeof(fullname), "%s/pdfXXXXXX", dir);
+        //snprintf(fullname, sizeof(fullname), "%s/pdfXXXXXX", dir);
 
                 sprintf(tmpnm, "%s/", mdir);
                 snprintf(name, sizeof(name), "klammailXXXXXX");
@@ -153,26 +151,17 @@ int clamdscan(struct optstruct *opt)
                 while((bytes = read(0, buff, BUFFSIZE)) > 0) {
 
                         if(write(fd, buff, bytes) != bytes) {
-                                cli_dbgmsg("clamdmail -> Can't write() file.\n");
+/*                                cli_dbgmsg("clamdmail -> Can't write() file.\n");*/
                                 close(fd);
                                 return CL_EMEM;
                         }
                 }
 
                 if(fsync(fd) == -1) {
-                        cli_dbgmsg("fsync() failed for descriptor %d\n", fd);
+//                         cli_dbgmsg("fsync() failed for descriptor %d\n", fd);
                         close(fd);
                         return CL_EFSYNC;
                 }
-                /*if (!(tmp = fdopen(fd,"r"))){
-                        mprintf("@Can't open file \n");
-                        return 54;
-                }
-                lseek(fd, 0, SEEK_SET);*/
-                /*close(fd);*/
-                /*
-                * Extract the attachments into the temporary directory
-                */
 
                 close(fd);
 
@@ -184,70 +173,56 @@ int clamdscan(struct optstruct *opt)
                 ret = 0;
                 ret = client(tmpnm, opt, &virname);
 
-        
+
+
                 /* load all available databases from default directory */
                 if((ret == 2)) {
                         startclamd(opt);
                         if(optc(opt, 'd')) {
-                                stat(getargc(opt, 'd'), &sb);
-                                switch(sb.st_mode & S_IFMT) {
-                                        case S_IFREG:
-                                        if((ret = cl_loaddb(getargc(opt, 'd'), &root, &no))) {
-                                                mprintf("@%s\n", cl_strerror(ret));
-                                                return 50;
-                                        }
-                                        break;
-                                        case S_IFDIR:
-                                        if((ret = cl_loaddbdir(getargc(opt, 'd'), &root, &no))) {
-                                                mprintf("@%s\n", cl_strerror(ret));
-                                                return 50;
-                                        }
-                                        break;
-                                        default:
-                                        mprintf("@%s: Not supported database file type\n", getargc(opt, 'd'));
-                                        return 50;
-                                        }
+                                if((ret = cl_load(getargc(opt, 'd'), &engine, &no, CL_DB_STDOPT))) {
+                                    printf("cl_load: %s\n", cl_strerror(ret));
+                                    close(fd);
+                                    return 50;
+                                }
                         }else{
-                                if((ret = cl_loaddbdir(cl_retdbdir(), &root, &no))) {
+                                if((ret = cl_loaddbdir(cl_retdbdir(), &engine, &no, CL_DB_STDOPT))) {
                                 printf("cl_loaddbdir: %s\n", cl_strerror(ret));
                                 close(fd);
                                 exit(2);
                                 }
                         }	
-                        /* build the final trie */
-                        if((ret = cl_build(root))) {
-        //		printf("Database initialization error: %s\n", cl_strerror(ret));;
-                                cl_free(root); /* free the partial trie */
-                                close(fd);
-                                exit(2);
+
+                        /* build engine */
+                        if((ret = cl_build(engine))) {
+                            printf("Database initialization error: %s\n", cl_strerror(ret));;
+                            cl_free(engine);
+                            close(fd);
+                            exit(2);
                         }
-                        
                         /* set up archive limits */
                         memset(&limits, 0, sizeof(struct cl_limits));
                         limits.maxfiles = 1000; /* max files */
-                        limits.maxfilesize = 10 * 1048576; /* maximal archived file size == 10 Mb */
-                        limits.maxreclevel = 5; /* maximal recursion level */
-                        limits.maxratio = 200; /* maximal compression ratio */
-                        limits.archivememlim = 0; /* disable memory limit for bzip2 scanner */
-                        
-                        ret = cl_scandesc(fd, &virname, &size, root, &limits, CL_SCAN_STDOPT | CL_ARCHIVE | CL_MAIL | CL_OLE2 | CL_SCAN_HTML);
+                        limits.maxfilesize = 10 * 1048576; /* maximum size of archived/compressed
+                                                            * file (files exceeding this limit
+                                                            * will be ignored)
+                                                            */
+                        /*limits.maxreclevel = 5;*/ /* maximum recursion level for archives */
+                        /*limits.maxmailrec = 64;*/ /* maximum recursion level for mail files */
+                        /*limits.maxratio = 200;*/ /* maximum compression ratio */
+                        limits.archivememlim = 1;
+                        ret = cl_scandesc(fd, &virname, &size, engine, &limits, CL_SCAN_STDOPT | CL_ARCHIVE | CL_MAIL | CL_OLE2 | CL_SCAN_HTML);
 
                 }
-//		printf("Loaded %d signatures.\n", no);
-                
-                
+
                 /* scan descriptor (with archive and mail scanning enabled) */
-        
                 close(fd);
-                
                 fd = open(tmpnm,O_RDWR, S_IRWXU);
 
-                
                 spoolstdin(fd, ret, &virname, &bndrystore, opt);
 
                 if((ret == 2))
-                        cl_free(root);
-                        
+                    cl_free(engine);
+
                 unlink(tmpnm);
 
 
@@ -393,7 +368,7 @@ int spoolstdin(int fd, int ret, char **virname, const char **bndrystore, struct
                                 while((bytes = read(fd, buff, BUFFSIZE)) > 0) {
         
                                         if(write(1, buff, bytes) != bytes) {
-                                        cli_dbgmsg("clamdmail -> Can't write() file.\n");
+//                                         cli_dbgmsg("clamdmail -> Can't write() file.\n");
                                                 close(fd);
                                                 return CL_EMEM;
                                         }
@@ -609,7 +584,4 @@ void startclamd(struct optstruct *opt)
 
         sleep(1);
         unlink(fullpath);
-        
-        //execlp("/usr/local/sbin/clamd", "/usr/local/sbin/clamd", ("--config-file=%s",tmpnm),  NULL);
-        
 }
