@@ -31,6 +31,7 @@
 #include <qpushbutton.h>
 #include <qcolor.h>
 #include <qtooltip.h> //QToolTip::palette()
+#include <kdebug.h>
 
 static int counter = 0;
 
@@ -185,7 +186,7 @@ void ScanViewer::processOutput()
             int fnameStartPoint = 0;
             int fnameEndPoint = item2.findRev(":");
             QString tmpFName = item2.mid(fnameStartPoint,(fnameEndPoint - fnameStartPoint));
-
+            tmpFName = i18n(tmpFName);
             if ((pos = (item2.find(" FOUND"))) != -1){
             //if ((pos = buf.section('\n',j,j).find("FOUND")) != -1){
                 QString tmpVirusName = item2.mid((fnameEndPoint+1),(item2.length() - (fnameEndPoint+1)));
@@ -392,19 +393,25 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
     if (KlamavConfig::noFilesToExtract() > 0)
         options += "--max-files=" + QString("%1").arg(KlamavConfig::noFilesToExtract()) + " ";
 
-    if (KlamavConfig::mBsToExtract() > 0)
-        options += "--max-space=" + QString("%1").arg(KlamavConfig::mBsToExtract()) + " ";
-        
-    if (KlamavConfig::compressionRatio() > 0)
-        options += "--max-ratio=" + QString("%1").arg(KlamavConfig::compressionRatio()) + " ";
+//     if (KlamavConfig::mBsToExtract() > 0)
+//         options += "--max-space=" + QString("%1").arg(KlamavConfig::mBsToExtract()) + " ";
+//         
+//     if (KlamavConfig::compressionRatio() > 0)
+//         options += "--max-ratio=" + QString("%1").arg(KlamavConfig::compressionRatio()) + " ";
 
     if (KlamavConfig::recursionLevel() > 0)
         options += "--max-recursion=" + QString("%1").arg(KlamavConfig::recursionLevel()) + " ";
 
 
+    if (KlamavConfig::maxFileSize() > 0)
+        options += "--max-filesize=" + QString("%1").arg(KlamavConfig::maxFileSize()) + "M ";
+
+    if (KlamavConfig::maxScanSize() > 0)
+        options += "--max-scansize=" + QString("%1").arg(KlamavConfig::maxScanSize()) + "M ";
+  
     //config->setGroup("Klamscan");
-    if (KlamavConfig::virusLimitsExceeded())
-        options += "--block-max ";
+//     if (KlamavConfig::virusLimitsExceeded())
+//         options += "--block-max ";
 
     if (KlamavConfig::virusEncrypted())
         options += "--block-encrypted ";
@@ -442,7 +449,7 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
     }
     
     if (KlamavConfig::scanArj()){
-        options += "--unarj";
+        options += "--arj";
         if ((KlamavConfig::arjUsing()) != "")
             options += "="+(KlamavConfig::arjUsing())+" ";
         else
@@ -497,7 +504,12 @@ void ScanViewer::slotScan(const QStringList & filepattern, int mode, bool recurs
             options+=" ";
     }
 
-    
+    kdDebug() << "clamscan -v "
+    << excludes << " " 
+    << dbpath << " " 
+    << options << " "
+    << "'" + m_filepattern.join("' '") + "'" << endl;
+
     childproc = new KProcIO();
     childproc->setUseShell(TRUE);
     childproc->setUsePty (KProcIO::Stdout,TRUE);
@@ -735,7 +747,7 @@ void  ScanViewer::Quarantine(){
                 (resultview->findItem(fname,0))->setText(2,"Quarantined");
                     (resultview->findItem(fname,0))->setPixmap( 0, SmallIcon("klamavbw") );
                 chmod((const char *)qname,0400);
-        CollectionDB::instance()->insertEvent("Quarantine",QString("Quarantined"),fname);
+                CollectionDB::instance()->insertEvent("Quarantine",QString("Quarantined"),fname);
 
             }else{
                 KMessageBox::information (this,i18n("<p>There was a problem quarantining <b>%1</b>. Check your diskspace, the permissions on your quarantine location and whether a file with the same name already exists in the quarantine. </p>").arg(fname));
