@@ -61,7 +61,7 @@ public:
      */
     
     //void  setDirName(QString);
-    void slotScan(const QStringList & filepattern, int mode, bool recursive);
+    void slotScan(const QStringList & filepattern, int mode, bool recursive, bool dcopscan);
     void slotCancel();
     void slotStartAgain();
     bool scanGoingOn();
